package com.fuyuanshen.app.service;

import com.fuyuanshen.app.domain.vo.AppUserVo;
import com.fuyuanshen.app.domain.bo.AppUserBo;
import com.fuyuanshen.common.mybatis.core.page.TableDataInfo;
import com.fuyuanshen.common.mybatis.core.page.PageQuery;

import java.util.Collection;
import java.util.List;

/**
 * APP用户信息Service接口
 *
 * @author Lion Li
 * @date 2025-06-27
 */
public interface IAppUserService {

    /**
     * 查询APP用户信息
     *
     * @param userId 主键
     * @return APP用户信息
     */
    AppUserVo queryById(Long userId);

    /**
     * 分页查询APP用户信息列表
     *
     * @param bo        查询条件
     * @param pageQuery 分页参数
     * @return APP用户信息分页列表
     */
    TableDataInfo<AppUserVo> queryPageList(AppUserBo bo, PageQuery pageQuery);

    /**
     * 查询符合条件的APP用户信息列表
     *
     * @param bo 查询条件
     * @return APP用户信息列表
     */
    List<AppUserVo> queryList(AppUserBo bo);

    /**
     * 新增APP用户信息
     *
     * @param bo APP用户信息
     * @return 是否新增成功
     */
    Boolean insertByBo(AppUserBo bo);

    /**
     * 修改APP用户信息
     *
     * @param bo APP用户信息
     * @return 是否修改成功
     */
    Boolean updateByBo(AppUserBo bo);

    /**
     * 校验并批量删除APP用户信息信息
     *
     * @param ids     待删除的主键集合
     * @param isValid 是否进行有效性校验
     * @return 是否删除成功
     */
    Boolean deleteWithValidByIds(Collection<Long> ids, Boolean isValid);
}
